@@ -1,6 +1,7 @@
-use std::io::Write;
+use std::io::{self, Write};
 use serde::{ser, Serialize};
 
+use crate::byte_counter::ByteCounter;
 use crate::error::{Error, ErrorKind, Result};
 use crate::constants;
 use crate::varint::VarInt;
@@ -9,6 +10,15 @@ use crate::varint::VarInt;
 // User functions                                                            //
 ///////////////////////////////////////////////////////////////////////////////
 
+pub fn serialize_into<T, W>(writer: &mut W, value: &T) -> Result<()>
+where
+	T: Serialize,
+	W: Write
+{
+	let mut serializer = Serializer::new_unstarted(writer)?;
+	value.serialize(&mut serializer)
+}
+
 pub fn to_bytes<T: Serialize>(value: &T) -> Result<Vec<u8>> {
 	let mut byte_stream = Vec::<u8>::new(); // Vec<u8> implements Write
 	let mut serializer = Serializer::new_unstarted(&mut byte_stream)?;
@@ -16,6 +26,15 @@ pub fn to_bytes<T: Serialize>(value: &T) -> Result<Vec<u8>> {
 	Ok(byte_stream)
 }
 
+pub fn serialized_size<T>(value: &T) -> Result<usize>
+where
+T: Serialize
+{
+	let mut sink_counter = ByteCounter::new(io::sink());
+	serialize_into(&mut sink_counter, value)?;
+	Ok(sink_counter.bytes_written())
+}
+
 ///////////////////////////////////////////////////////////////////////////////
 // Serializer                                                                //
 ///////////////////////////////////////////////////////////////////////////////
@@ -167,7 +186,8 @@ where
 		}
 
 		if self.storage_format == EpeeStorageFormat::Array && type_code != self.element_type {
-			return Err(Error::new_no_msg(ErrorKind::ArrayMixedTypes));
+			let msg = format!("type_codes: {} -> {}", self.element_type, type_code);
+			return Err(Error::new(ErrorKind::ArrayMixedTypes, msg));
 		} else if self.serializing_key && type_code != constants::SERIALIZE_TYPE_STRING {
 			return Err(Error::new_no_msg(ErrorKind::KeyBadType))
 		}
@@ -218,7 +238,7 @@ where
 
 	fn serialize_bool(self, v: bool) -> Result<()> {
 		self.serialize_start_and_type_code(constants::SERIALIZE_TYPE_BOOL)?;
-		self.serialize_u8(v.into())
+		self.write_raw(&[v as u8])
 	}
 
 	fn serialize_f32(self, v: f32) -> Result<()> {
